@@ -5,7 +5,7 @@ exclude_functions <- function(funs, to_exclude) {
 
   # functions to exclude regardless of package
   if (all(!has_name)) {
-    out <- lapply(X = funs, FUN = setdiff, y = to_exclude)
+    out <- lapply(X = funs, FUN = setdiff, y = unlist(to_exclude))
 
     # functions to exclude from specific packages
   } else if (all(has_name)) {
